@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -37,12 +37,15 @@ import ghidra.app.context.ProgramLocationActionContext;
 import ghidra.app.events.ProgramActivatedPluginEvent;
 import ghidra.app.events.ProgramClosedPluginEvent;
 import ghidra.app.plugin.PluginCategoryNames;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.event.TraceClosedPluginEvent;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
 import ghidra.app.services.*;
 import ghidra.async.AsyncLazyMap;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.emulation.DebuggerPcodeEmulatorFactory;
+import ghidra.debug.api.emulation.DebuggerPcodeMachine;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.plugintool.*;
 import ghidra.framework.plugintool.annotation.AutoServiceConsumed;
 import ghidra.framework.plugintool.util.PluginStatus;
@@ -60,8 +63,7 @@ import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.TraceSnapshot;
 import ghidra.trace.model.time.schedule.*;
 import ghidra.trace.model.time.schedule.Scheduler.RunResult;
-import ghidra.util.HelpLocation;
-import ghidra.util.Msg;
+import ghidra.util.*;
 import ghidra.util.classfinder.ClassSearcher;
 import ghidra.util.datastruct.ListenerSet;
 import ghidra.util.exception.CancelledException;
@@ -294,7 +296,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 				.forgetValues((key, l) -> true);
 	protected final Map<CachedEmulator, Integer> busy = new LinkedHashMap<>();
 	protected final ListenerSet<EmulatorStateListener> stateListeners =
-		new ListenerSet<>(EmulatorStateListener.class);
+		new ListenerSet<>(EmulatorStateListener.class, true);
 
 	class BusyEmu implements AutoCloseable {
 		private final CachedEmulator ce;
@@ -313,7 +315,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 				}
 			}
 			if (fire) {
-				stateListeners.fire.running(ce);
+				stateListeners.invoke().running(ce);
 			}
 		}
 
@@ -331,7 +333,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 				}
 			}
 			if (fire) {
-				stateListeners.fire.stopped(ce);
+				stateListeners.invoke().stopped(ce);
 			}
 		}
 
@@ -343,7 +345,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 	@AutoServiceConsumed
 	private DebuggerTraceManagerService traceManager;
 	@AutoServiceConsumed
-	private DebuggerModelService modelService;
+	private DebuggerTargetService targetService;
 	@AutoServiceConsumed
 	private DebuggerPlatformService platformService;
 	@AutoServiceConsumed
@@ -472,8 +474,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 
 	private boolean emulateAddThreadEnabled(ProgramLocationActionContext ctx) {
 		Program programOrView = ctx.getProgram();
-		if (programOrView instanceof TraceProgramView) {
-			TraceProgramView view = (TraceProgramView) programOrView;
+		if (programOrView instanceof TraceProgramView view) {
 			if (!ProgramEmulationUtils.isEmulatedProgram(view.getTrace())) {
 				return false;
 			}
@@ -503,8 +504,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 
 	private void emulateAddThreadActivated(ProgramLocationActionContext ctx) {
 		Program programOrView = ctx.getProgram();
-		if (programOrView instanceof TraceProgramView) {
-			TraceProgramView view = (TraceProgramView) programOrView;
+		if (programOrView instanceof TraceProgramView view) {
 			Trace trace = view.getTrace();
 			Address tracePc = ctx.getAddress();
 
@@ -726,7 +726,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 			}
 		}
 		DebuggerPcodeMachine<?> emu = emulatorFactory.create(tool, platform, time.getSnap(),
-			modelService == null ? null : modelService.getRecorder(trace));
+			targetService == null ? null : targetService.getTarget(trace));
 		try (BusyEmu be = new BusyEmu(new CachedEmulator(key.trace, emu))) {
 			installBreakpoints(key.trace, key.time.getSnap(), be.ce.emulator());
 			monitor.initialize(time.totalTickCount());
@@ -782,7 +782,12 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 			TraceThread eventThread = key.time.getEventThread(key.trace);
 			be.ce.emulator().setSoftwareInterruptMode(SwiMode.IGNORE_STEP);
 			RunResult result = scheduler.run(key.trace, eventThread, be.ce.emulator(), monitor);
-			key = new CacheKey(key.platform, key.time.advanced(result.schedule()));
+			if (result.schedule().hasSteps()) {
+				key = new CacheKey(key.platform, key.time.dropPSteps().advanced(result.schedule()));
+			}
+			else {
+				key = new CacheKey(key.platform, key.time.advanced(result.schedule()));
+			}
 			Msg.info(this, "Stopped emulation at " + key.time);
 			TraceSnapshot destSnap = writeToScratch(key, be.ce);
 			cacheEmulator(key, be.ce);
@@ -812,6 +817,23 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 		}
 	}
 
+	@Override
+	public Trace launchProgram(Program program, Address address) throws IOException {
+		Trace trace = null;
+		try {
+			trace = ProgramEmulationUtils.launchEmulationTrace(program, address, this);
+			traceManager.openTrace(trace);
+			traceManager.activateTrace(trace);
+			Swing.allowSwingToProcessEvents();
+		}
+		finally {
+			if (trace != null) {
+				trace.release(this);
+			}
+		}
+		return trace;
+	}
+
 	@Override
 	public long emulate(TracePlatform platform, TraceSchedule time, TaskMonitor monitor)
 			throws CancelledException {
@@ -860,7 +882,7 @@ public class DebuggerEmulationServicePlugin extends Plugin implements DebuggerEm
 	}
 
 	@AutoServiceConsumed
-	private void setModelService(DebuggerModelService modelService) {
+	private void setModelService(DebuggerTargetService targetService) {
 		cache.clear();
 	}
 
