@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -20,7 +20,6 @@ import static org.junit.Assert.*;
 import java.awt.event.MouseEvent;
 import java.io.IOException;
 import java.util.*;
-import java.util.concurrent.TimeUnit;
 
 import org.junit.*;
 import org.junit.experimental.categories.Category;
@@ -30,7 +29,6 @@ import docking.widgets.filechooser.GhidraFileChooser;
 import docking.widgets.table.DynamicTableColumn;
 import generic.Unique;
 import generic.test.category.NightlyCategory;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.gui.*;
 import ghidra.app.plugin.core.debug.gui.DebuggerBlockChooserDialog.MemoryBlockRow;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources.AbstractImportFromFileSystemAction;
@@ -44,40 +42,69 @@ import ghidra.app.plugin.core.debug.gui.modules.DebuggerModuleMapProposalDialog.
 import ghidra.app.plugin.core.debug.gui.modules.DebuggerModulesProvider.MapModulesAction;
 import ghidra.app.plugin.core.debug.gui.modules.DebuggerModulesProvider.MapSectionsAction;
 import ghidra.app.plugin.core.debug.gui.modules.DebuggerSectionMapProposalDialog.SectionMapTableColumns;
-import ghidra.app.plugin.core.debug.mapping.DebuggerTargetTraceMapper;
-import ghidra.app.plugin.core.debug.mapping.ObjectBasedDebuggerTargetTraceMapper;
+import ghidra.app.plugin.core.debug.service.tracemgr.DebuggerTraceManagerServiceTestAccess;
 import ghidra.app.services.DebuggerListingService;
-import ghidra.app.services.ModuleMapProposal.ModuleMapEntry;
-import ghidra.app.services.SectionMapProposal.SectionMapEntry;
-import ghidra.app.services.TraceRecorder;
-import ghidra.dbg.attributes.TargetPrimitiveDataType.DefaultTargetPrimitiveDataType;
-import ghidra.dbg.attributes.TargetPrimitiveDataType.PrimitiveKind;
-import ghidra.dbg.model.TestTargetModule;
-import ghidra.dbg.model.TestTargetTypedefDataType;
-import ghidra.dbg.target.*;
-import ghidra.dbg.target.schema.SchemaContext;
-import ghidra.dbg.target.schema.TargetObjectSchema.SchemaName;
-import ghidra.dbg.target.schema.XmlSchemaContext;
-import ghidra.dbg.util.*;
+import ghidra.debug.api.modules.ModuleMapProposal.ModuleMapEntry;
+import ghidra.debug.api.modules.SectionMapProposal.SectionMapEntry;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.main.DataTreeDialog;
 import ghidra.plugin.importer.ImporterPlugin;
 import ghidra.program.model.address.*;
-import ghidra.program.model.data.DataType;
-import ghidra.program.model.lang.CompilerSpecID;
-import ghidra.program.model.lang.LanguageID;
 import ghidra.program.model.mem.MemoryBlock;
 import ghidra.trace.database.module.TraceObjectSection;
 import ghidra.trace.model.Lifespan;
 import ghidra.trace.model.Trace;
-import ghidra.trace.model.data.TraceBasedDataTypeManager;
-import ghidra.trace.model.modules.*;
-import ghidra.trace.model.symbol.TraceSymbol;
-import ghidra.trace.model.target.*;
+import ghidra.trace.model.memory.TraceObjectMemoryRegion;
+import ghidra.trace.model.modules.TraceObjectModule;
+import ghidra.trace.model.modules.TraceStaticMapping;
+import ghidra.trace.model.target.TraceObject;
 import ghidra.trace.model.target.TraceObject.ConflictResolution;
+import ghidra.trace.model.target.TraceObjectManager;
+import ghidra.trace.model.target.path.*;
+import ghidra.trace.model.target.schema.SchemaContext;
+import ghidra.trace.model.target.schema.TraceObjectSchema.SchemaName;
+import ghidra.trace.model.target.schema.XmlSchemaContext;
 import ghidra.util.table.GhidraTable;
 
 @Category(NightlyCategory.class)
-public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUITest {
+public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerTest {
+
+	public static final String CTX_XML = """
+			<context>
+			    <schema name='Session' elementResync='NEVER' attributeResync='ONCE'>
+			        <attribute name='Processes' schema='ProcessContainer' />
+			    </schema>
+			    <schema name='ProcessContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element index='1' schema='Process' />
+			    </schema>
+			    <schema name='Process' elementResync='NEVER' attributeResync='ONCE'>
+			        <attribute name='Modules' schema='ModuleContainer' />
+			        <attribute name='Memory' schema='RegionContainer' />
+			    </schema>
+			    <schema name='RegionContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Region' />
+			    </schema>
+			    <schema name='Region' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='MemoryRegion' />
+			    </schema>
+			    <schema name='ModuleContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Module' />
+			    </schema>
+			    <schema name='Module' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='Module' />
+			        <attribute name='Sections' schema='SectionContainer' />
+			    </schema>
+			    <schema name='SectionContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Section' />
+			    </schema>
+			    <schema name='Section' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='Section' />
+			    </schema>
+			</context>""";
 
 	DebuggerModulesProvider provider;
 
@@ -91,25 +118,6 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 
 	protected SchemaContext ctx;
 
-	@Override
-	protected DebuggerTargetTraceMapper createTargetTraceMapper(TargetObject target)
-			throws Exception {
-		return new ObjectBasedDebuggerTargetTraceMapper(target,
-			new LanguageID("DATA:BE:64:default"), new CompilerSpecID("pointer64"), Set.of());
-	}
-
-	@Override
-	protected TraceRecorder recordAndWaitSync() throws Throwable {
-		TraceRecorder recorder = super.recordAndWaitSync();
-		useTrace(recorder.getTrace());
-		return recorder;
-	}
-
-	@Override
-	protected TargetObject chooseTarget() {
-		return mb.testModel.session;
-	}
-
 	@Override
 	protected void createTrace(String langID) throws IOException {
 		super.createTrace(langID);
@@ -121,59 +129,9 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		}
 	}
 
-	@Override
-	protected void useTrace(Trace trace) {
-		super.useTrace(trace);
-		if (trace.getObjectManager().getRootObject() != null) {
-			// If live, recorder will have created it
-			return;
-		}
-		try {
-			activateObjectsMode();
-		}
-		catch (Exception e) {
-			throw new AssertionError(e);
-		}
-	}
-
 	public void activateObjectsMode() throws Exception {
 		// NOTE the use of index='1' allowing object-based managers to ID unique path
-		ctx = XmlSchemaContext.deserialize("""
-				<context>
-				    <schema name='Session' elementResync='NEVER' attributeResync='ONCE'>
-				        <attribute name='Processes' schema='ProcessContainer' />
-				    </schema>
-				    <schema name='ProcessContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element index='1' schema='Process' />
-				    </schema>
-				    <schema name='Process' elementResync='NEVER' attributeResync='ONCE'>
-				        <attribute name='Modules' schema='ModuleContainer' />
-				        <attribute name='Memory' schema='RegionContainer' />
-				    </schema>
-				    <schema name='RegionContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Region' />
-				    </schema>
-				    <schema name='Region' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='MemoryRegion' />
-				    </schema>
-				    <schema name='ModuleContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Module' />
-				    </schema>
-				    <schema name='Module' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='Module' />
-				        <attribute name='Sections' schema='SectionContainer' />
-				    </schema>
-				    <schema name='SectionContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Section' />
-				    </schema>
-				    <schema name='Section' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='Section' />
-				    </schema>
-				</context>""");
+		ctx = XmlSchemaContext.deserialize(CTX_XML);
 
 		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getObjectManager().createRootObject(ctx.getSchema(new SchemaName("Session")));
@@ -181,32 +139,33 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 	}
 
 	protected void addRegionsFromModules() throws Exception {
-		PathPattern regionPattern = new PathPattern(PathUtils.parse("Processes[1].Memory[]"));
+		PathPattern regionPattern = PathFilter.parse("Processes[1].Memory[]");
 		TraceObjectManager om = tb.trace.getObjectManager();
 		try (Transaction tx = tb.startTransaction()) {
 			TraceObject root = om.getRootObject();
 			for (TraceObject module : (Iterable<TraceObject>) () -> root
-					.querySuccessorsTargetInterface(Lifespan.at(0), TargetModule.class, true)
+					.findSuccessorsInterface(Lifespan.at(0), TraceObjectModule.class, true)
 					.map(p -> p.getDestination(root))
 					.iterator()) {
 				String moduleName = module.getCanonicalPath().index();
 				Lifespan span = module.getLife().bound();
 				for (TraceObject section : (Iterable<TraceObject>) () -> module
-						.querySuccessorsTargetInterface(Lifespan.at(0), TargetSection.class, true)
+						.findSuccessorsInterface(Lifespan.at(0), TraceObjectSection.class,
+							true)
 						.map(p -> p.getDestination(root))
 						.iterator()) {
 					String sectionName = section.getCanonicalPath().index();
-					TraceObject region = om.createObject(TraceObjectKeyPath
-							.of(regionPattern.applyKeys(moduleName + ":" + sectionName)
-									.getSingletonPath()))
+					TraceObject region = om
+							.createObject(regionPattern.applyKeys(moduleName + ":" + sectionName)
+									.getSingletonPath())
 							.insert(span, ConflictResolution.TRUNCATE)
 							.getDestination(root);
-					region.setAttribute(span, TargetMemoryRegion.RANGE_ATTRIBUTE_NAME,
-						section.getAttribute(0, TargetSection.RANGE_ATTRIBUTE_NAME).getValue());
-					region.setAttribute(span, TargetMemoryRegion.READABLE_ATTRIBUTE_NAME, true);
-					region.setAttribute(span, TargetMemoryRegion.WRITABLE_ATTRIBUTE_NAME,
+					region.setAttribute(span, TraceObjectMemoryRegion.KEY_RANGE,
+						section.getAttribute(0, TraceObjectSection.KEY_RANGE).getValue());
+					region.setAttribute(span, TraceObjectMemoryRegion.KEY_READABLE, true);
+					region.setAttribute(span, TraceObjectMemoryRegion.KEY_WRITABLE,
 						".data".equals(sectionName));
-					region.setAttribute(span, TargetMemoryRegion.EXECUTABLE_ATTRIBUTE_NAME,
+					region.setAttribute(span, TraceObjectMemoryRegion.KEY_EXECUTABLE,
 						".text".equals(sectionName));
 				}
 			}
@@ -214,15 +173,15 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 	}
 
 	protected TraceObjectModule addModule(String name, AddressRange range, Lifespan span) {
-		PathPattern modulePattern = new PathPattern(PathUtils.parse("Processes[1].Modules[]"));
+		PathPattern modulePattern = PathFilter.parse("Processes[1].Modules[]");
 		TraceObjectManager om = tb.trace.getObjectManager();
 		TraceObjectModule module = Objects.requireNonNull(
-			om.createObject(TraceObjectKeyPath.of(modulePattern.applyKeys(name).getSingletonPath()))
+			om.createObject(modulePattern.applyKeys(name).getSingletonPath())
 					.insert(span, ConflictResolution.TRUNCATE)
 					.getDestination(null)
 					.queryInterface(TraceObjectModule.class));
-		module.getObject().setAttribute(span, TargetModule.MODULE_NAME_ATTRIBUTE_NAME, name);
-		module.getObject().setAttribute(span, TargetModule.RANGE_ATTRIBUTE_NAME, range);
+		module.getObject().setAttribute(span, TraceObjectModule.KEY_MODULE_NAME, name);
+		module.getObject().setAttribute(span, TraceObjectModule.KEY_RANGE, range);
 		return module;
 	}
 
@@ -236,7 +195,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 				.insert(span, ConflictResolution.TRUNCATE)
 				.getDestination(null)
 				.queryInterface(TraceObjectSection.class));
-		section.getObject().setAttribute(span, TargetSection.RANGE_ATTRIBUTE_NAME, range);
+		section.getObject().setAttribute(span, TraceObjectSection.KEY_RANGE, range);
 		return section;
 	}
 
@@ -277,14 +236,20 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 	protected void assertModuleRow(int pos, Object object, String name, Address start, Address end,
 			long length) {
 		ValueRow row = provider.modulesPanel.getAllItems().get(pos);
-		DynamicTableColumn<ValueRow, ?, Trace> nameCol =
-			provider.modulesPanel.getColumnByNameAndType("Name", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> baseCol =
-			provider.modulesPanel.getColumnByNameAndType("Base", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> maxCol =
-			provider.modulesPanel.getColumnByNameAndType("Max", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> lengthCol =
-			provider.modulesPanel.getColumnByNameAndType("Length", ValueProperty.class).getValue();
+		var tableModel = QueryPanelTestHelper.getTableModel(provider.modulesPanel);
+		GhidraTable table = QueryPanelTestHelper.getTable(provider.modulesPanel);
+		DynamicTableColumn<ValueRow, ?, Trace> nameCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Name", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> baseCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Base", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> maxCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Max", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> lengthCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Length", ValueProperty.class)
+				.column();
 
 		assertSame(object, row.getValue().getValue());
 		assertEquals(name, rowColVal(row, nameCol));
@@ -296,17 +261,23 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 	protected void assertSectionRow(int pos, Object object, String moduleName, String name,
 			Address start, Address end, long length) {
 		ValueRow row = provider.sectionsPanel.getAllItems().get(pos);
-		DynamicTableColumn<ValueRow, ?, Trace> moduleNameCol =
-			provider.sectionsPanel.getColumnByNameAndType("Module Name", ValueProperty.class)
-					.getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> nameCol =
-			provider.sectionsPanel.getColumnByNameAndType("Name", String.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> startCol =
-			provider.sectionsPanel.getColumnByNameAndType("Start", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> endCol =
-			provider.sectionsPanel.getColumnByNameAndType("End", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> lengthCol =
-			provider.sectionsPanel.getColumnByNameAndType("Length", ValueProperty.class).getValue();
+		var tableModel = QueryPanelTestHelper.getTableModel(provider.sectionsPanel);
+		GhidraTable table = QueryPanelTestHelper.getTable(provider.sectionsPanel);
+		DynamicTableColumn<ValueRow, ?, Trace> moduleNameCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Module Name", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> nameCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Name", String.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> startCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Start", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> endCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "End", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> lengthCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Length", ValueProperty.class)
+				.column();
 
 		assertSame(object, row.getValue().getValue());
 		assertEquals(moduleName, rowColVal(row, moduleNameCol));
@@ -446,7 +417,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		});
 	}
 
-	@Test
+	// @Test // Not gonna with write-behind cache
 	public void testUndoRedoCausesUpdateInProvider() throws Exception {
 		createAndOpenTrace();
 
@@ -467,6 +438,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 
 	@Test
 	public void testActivatingNoTraceEmptiesProvider() throws Exception {
+		DebuggerTraceManagerServiceTestAccess.setEnsureActiveTrace(traceManager, false);
 		createAndOpenTrace();
 
 		addModules();
@@ -536,7 +508,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 
 	@Test
 	public void testActionMapModules() throws Exception {
-		assertFalse(provider.actionMapModules.isEnabled());
+		assertDisabled(provider, provider.actionMapModules);
 
 		createAndOpenTrace();
 		createAndOpenProgramFromTrace();
@@ -548,7 +520,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		waitForSwing();
 
 		// Still
-		assertFalse(provider.actionMapModules.isEnabled());
+		assertDisabled(provider, provider.actionMapModules);
 
 		try (Transaction tx = program.openTransaction("Change name")) {
 			program.setImageBase(addr(program, 0x00400000), true);
@@ -561,7 +533,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		waitForPass(() -> assertModuleTableSize(2));
 
 		runSwing(() -> provider.setSelectedModules(Set.of(modExe)));
-		assertTrue(provider.actionMapModules.isEnabled());
+		assertEnabled(provider, provider.actionMapModules);
 
 		performEnabledAction(provider, provider.actionMapModules, false);
 
@@ -603,7 +575,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 
 	@Test
 	public void testActionMapSections() throws Exception {
-		assertFalse(provider.actionMapSections.isEnabled());
+		assertDisabled(provider, provider.actionMapSections);
 
 		createAndOpenTrace();
 		createAndOpenProgramFromTrace();
@@ -615,7 +587,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		waitForTasks();
 
 		// Still
-		assertFalse(provider.actionMapSections.isEnabled());
+		assertDisabled(provider, provider.actionMapSections);
 
 		MemoryBlock block = addBlock();
 		try (Transaction tx = program.openTransaction("Change name")) {
@@ -626,7 +598,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		waitForPass(() -> assertSectionTableSize(4));
 
 		runSwing(() -> provider.setSelectedSections(Set.of(secExeText)));
-		assertTrue(provider.actionMapSections.isEnabled());
+		assertEnabled(provider, provider.actionMapSections);
 
 		performEnabledAction(provider, provider.actionMapSections, false);
 
@@ -699,118 +671,6 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 			new AddressSet(listing.getCurrentSelection()));
 	}
 
-	@Test
-	@Ignore("This action is hidden until supported")
-	public void testActionCaptureTypes() throws Exception {
-		assertFalse(provider.actionCaptureTypes.isEnabled());
-		createTestModel();
-		mb.createTestProcessesAndThreads();
-
-		TraceRecorder recorder = modelService.recordTargetAndActivateTrace(mb.testProcess1,
-			createTargetTraceMapper(mb.testProcess1));
-		Trace trace = recorder.getTrace();
-
-		// TODO: A region should not be required first. Just to get a memMapper?
-		mb.testProcess1.addRegion("Memory[first_proc:.text]", mb.rng(0x55550000, 0x555500ff),
-			"rx");
-		TestTargetModule module =
-			mb.testProcess1.modules.addModule("Modules[first_proc]",
-				mb.rng(0x55550000, 0x555500ff));
-		// NOTE: A section should not be required at this point.
-		TestTargetTypedefDataType typedef = module.types.addTypedefDataType("myInt",
-			new DefaultTargetPrimitiveDataType(PrimitiveKind.SINT, 4));
-		waitForDomainObject(trace);
-
-		// Still
-		assertFalse(provider.actionCaptureTypes.isEnabled());
-
-		traceManager.activateTrace(trace);
-		waitForSwing();
-		TraceModule traceModule = waitForValue(() -> recorder.getTraceModule(module));
-		provider.setSelectedModules(Set.of(traceModule));
-		waitForSwing();
-		// TODO: When action is included, put this assertion back
-		//assertTrue(modulesProvider.actionCaptureTypes.isEnabled());
-
-		performEnabledAction(provider, provider.actionCaptureTypes, true);
-		waitForBusyTool(tool);
-		waitForDomainObject(trace);
-
-		// TODO: A separate action/script to transfer types from trace DTM into mapped program DTMs
-		TraceBasedDataTypeManager dtm = trace.getDataTypeManager();
-		TargetDataTypeConverter conv = new TargetDataTypeConverter(dtm);
-		DataType expType =
-			conv.convertTargetDataType(typedef).get(DEFAULT_WAIT_TIMEOUT, TimeUnit.MILLISECONDS);
-		// TODO: Some heuristic or convention to extract the module name, if applicable
-		waitForPass(() -> {
-			DataType actType = dtm.getDataType("/Modules[first_proc].Types/myInt");
-			assertTypeEquals(expType, actType);
-		});
-
-		// TODO: When capture-types action is included, put this assertion back
-		//assertTrue(modulesProvider.actionCaptureTypes.isEnabled());
-		waitForLock(trace);
-		recorder.stopRecording();
-		waitForSwing();
-		assertFalse(provider.actionCaptureTypes.isEnabled());
-	}
-
-	@Test
-	public void testActionCaptureSymbols() throws Throwable {
-		assertFalse(provider.actionCaptureSymbols.isEnabled());
-		createTestModel();
-		mb.createTestProcessesAndThreads();
-
-		TraceRecorder recorder = recordAndWaitSync();
-		traceManager.openTrace(recorder.getTrace());
-
-		// TODO: A region should not be required first. Just to get a memMapper?
-		mb.testProcess1.addRegion("first_proc:.text", mb.rng(0x55550000, 0x555500ff),
-			"rx");
-		TestTargetModule module =
-			mb.testProcess1.modules.addModule("first_proc", mb.rng(0x55550000, 0x555500ff));
-		// NOTE: A section should not be required at this point.
-		module.symbols.addSymbol("test", mb.addr(0x55550080), 8,
-			new DefaultTargetPrimitiveDataType(PrimitiveKind.UNDEFINED, 8));
-		waitForDomainObject(tb.trace);
-
-		// Still
-		assertFalse(provider.actionCaptureSymbols.isEnabled());
-
-		traceManager.activateTrace(tb.trace);
-		waitForTasks();
-		waitForPass(() -> {
-			TraceModule traceModule = recorder.getTraceModule(module);
-			assertNotNull(traceModule);
-			runSwing(() -> provider.setSelectedModules(Set.of(traceModule)));
-			assertTrue(provider.actionCaptureSymbols.isEnabled());
-		});
-
-		performEnabledAction(provider, provider.actionCaptureSymbols, true);
-		waitForBusyTool(tool);
-		waitForDomainObject(tb.trace);
-
-		// TODO: A separate action/script to transfer symbols from trace into mapped programs
-		// TODO: Let this action work on the TraceObjects instead of TargetObjects
-		// NOTE: Used types must go along.
-		Collection<? extends TraceSymbol> symbols =
-			tb.trace.getSymbolManager().allSymbols().getNamed("test");
-		assertEquals(1, symbols.size());
-		TraceSymbol sym = symbols.iterator().next();
-		// TODO: Some heuristic or convention to extract the module name, if applicable
-		assertEquals("Processes[1].Modules[first_proc].Symbols::test", sym.getName(true));
-		// NOTE: builder (b) is not initialized here
-		assertEquals(tb.addr(0x55550080),
-			sym.getAddress());
-		// TODO: Check data type once those are captured in Data units.
-
-		assertTrue(provider.actionCaptureSymbols.isEnabled());
-		waitForLock(tb.trace);
-		recorder.stopRecording();
-		waitForSwing();
-		assertFalse(provider.actionCaptureSymbols.isEnabled());
-	}
-
 	@Test
 	public void testActionImportFromFileSystem() throws Exception {
 		addPlugin(tool, ImporterPlugin.class);
@@ -858,7 +718,7 @@ public class DebuggerModulesProviderTest extends AbstractGhidraHeadedDebuggerGUI
 		for (ValueRow row : visibleSections()) {
 			assertEquals(modExe.getObject(), row.getValue()
 					.getChild()
-					.queryCanonicalAncestorsTargetInterface(TargetModule.class)
+					.findCanonicalAncestorsInterface(TraceObjectModule.class)
 					.findFirst()
 					.orElse(null));
 		}
