@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -22,6 +22,7 @@ import org.apache.commons.collections4.IteratorUtils;
 
 import generic.NestedIterator;
 import ghidra.program.database.ProgramDB;
+import ghidra.program.database.code.InstructionDB;
 import ghidra.program.database.function.OverlappingFunctionException;
 import ghidra.program.model.address.*;
 import ghidra.program.model.data.DataType;
@@ -37,15 +38,14 @@ import ghidra.trace.database.DBTrace;
 import ghidra.trace.database.guest.InternalTracePlatform;
 import ghidra.trace.database.listing.UndefinedDBTraceData;
 import ghidra.trace.database.memory.DBTraceMemorySpace;
-import ghidra.trace.database.symbol.DBTraceFunctionSymbol;
 import ghidra.trace.database.thread.DBTraceThread;
 import ghidra.trace.model.*;
 import ghidra.trace.model.listing.*;
 import ghidra.trace.model.memory.TraceMemoryRegion;
+import ghidra.trace.model.memory.TraceMemoryState;
 import ghidra.trace.model.program.TraceProgramView;
 import ghidra.trace.model.program.TraceProgramViewListing;
 import ghidra.trace.model.property.TracePropertyMapOperations;
-import ghidra.trace.model.symbol.TraceFunctionSymbol;
 import ghidra.trace.util.*;
 import ghidra.util.*;
 import ghidra.util.AddressIteratorAdapter;
@@ -67,8 +67,8 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 		public int getBytes(ByteBuffer buffer, int addressOffset) {
 			DBTraceMemorySpace mem = trace.getMemoryManager().get(this, false);
 			if (mem == null) {
-				// TODO: 0-fill instead? Will need to check memory space bounds.
-				return 0;
+				buffer.put((byte) 0);
+				return 1;
 			}
 			return mem.getViewBytes(program.snap, address.add(addressOffset), buffer);
 		}
@@ -161,7 +161,7 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 
 	protected AddressSet getAddressSet(Address start, boolean forward) {
 		AddressFactory factory = program.getAddressFactory();
-		AddressSet all = program.allAddresses;
+		AddressSetView all = program.getAllAddresses();
 		return forward
 				? factory.getAddressSet(start, all.getMaxAddress())
 				: factory.getAddressSet(all.getMinAddress(), start);
@@ -283,7 +283,7 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 	}
 
 	protected Iterator<TraceCodeUnit> getCodeUnitIterator(boolean forward) {
-		AddressSetView set = program.allAddresses;
+		AddressSetView set = program.getAllAddresses();
 		return getCodeUnitIterator(forward ? set.getMinAddress() : set.getMaxAddress(), forward);
 	}
 
@@ -302,7 +302,7 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 	}
 
 	protected Iterator<TraceData> getDataIterator(boolean forward) {
-		AddressSetView set = program.allAddresses;
+		AddressSetView set = program.getAllAddresses();
 		return getDataIterator(forward ? set.getMinAddress() : set.getMaxAddress(), forward);
 	}
 
@@ -710,18 +710,31 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 	}
 
 	@Override
-	@SuppressWarnings("rawtypes")
-	public PropertyMap getPropertyMap(String propertyName) {
+	public PropertyMap<?> getPropertyMap(String propertyName) {
 		// TODO Auto-generated method stub
 		return null;
 	}
 
 	@Override
 	public Instruction createInstruction(Address addr, InstructionPrototype prototype,
-			MemBuffer memBuf, ProcessorContextView context) throws CodeUnitInsertionException {
-		// TODO: Why memBuf? Can it vary from program memory?
+			MemBuffer memBuf, ProcessorContextView context, int forcedLengthOverride)
+			throws CodeUnitInsertionException {
+		int checkLengthOverride =
+			InstructionDB.checkLengthOverride(forcedLengthOverride, prototype);
+		int length = checkLengthOverride != 0 ? checkLengthOverride : prototype.getLength();
+		AddressRange range;
+		try {
+			range = new AddressRangeImpl(addr, length);
+		}
+		catch (AddressOverflowException e) {
+			throw new CodeUnitInsertionException("Code unit would extend beyond address space");
+		}
+		var mostRecent = program.memory.memoryManager.getViewMostRecentStateEntry(program.snap,
+			range, s -> s == TraceMemoryState.KNOWN);
+		long snap = mostRecent == null ? program.snap : mostRecent.getKey().getY2();
 		return codeOperations.instructions()
-				.create(Lifespan.nowOn(program.snap), addr, platform, prototype, context);
+				.create(Lifespan.nowOn(snap), addr, platform, prototype, context,
+					forcedLengthOverride);
 	}
 
 	@Override
@@ -867,13 +880,13 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 	}
 
 	@Override
-	public TraceFunctionSymbol createFunction(String name, Address entryPoint, AddressSetView body,
+	public Function createFunction(String name, Address entryPoint, AddressSetView body,
 			SourceType source) throws InvalidInputException, OverlappingFunctionException {
 		return program.functionManager.createFunction(name, entryPoint, body, source);
 	}
 
 	@Override
-	public TraceFunctionSymbol createFunction(String name, Namespace nameSpace, Address entryPoint,
+	public Function createFunction(String name, Namespace nameSpace, Address entryPoint,
 			AddressSetView body, SourceType source)
 			throws InvalidInputException, OverlappingFunctionException {
 		return program.functionManager.createFunction(name, nameSpace, entryPoint, body, source);
@@ -891,22 +904,12 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 
 	@Override
 	public List<Function> getGlobalFunctions(String name) {
-		return new ArrayList<>(program.trace.getSymbolManager().functions().getGlobalsNamed(name));
+		return List.of();
 	}
 
 	@Override
 	public List<Function> getFunctions(String namespace, String name) {
-		// NOTE: This implementation allows namespaces to contain the separator symbol
-		List<Function> result = new ArrayList<>();
-		for (DBTraceFunctionSymbol func : program.trace.getSymbolManager()
-				.functions()
-				.getNamed(
-					name)) {
-			if (namespace.equals(func.getParentNamespace().getName(true))) {
-				result.add(func);
-			}
-		}
-		return result;
+		return List.of();
 	}
 
 	@Override
@@ -916,7 +919,7 @@ public abstract class AbstractDBTraceProgramViewListing implements TraceProgramV
 
 	@Override
 	public FunctionIterator getExternalFunctions() {
-		return program.functionManager.getExternalFunctions();
+		return EmptyFunctionIterator.INSTANCE;
 	}
 
 	@Override
