@@ -30,6 +30,7 @@ import org.apache.commons.lang3.StringUtils;
 import docking.ActionContext;
 import docking.Tool;
 import docking.action.*;
+import docking.action.builder.ActionBuilder;
 import docking.actions.PopupActionProvider;
 import docking.widgets.tree.GTreeNode;
 import generic.jar.ResourceFile;
@@ -47,6 +48,7 @@ import ghidra.app.plugin.core.datamgr.util.DataDropOnBrowserHandler;
 import ghidra.app.plugin.core.datamgr.util.DataTypeChooserDialog;
 import ghidra.app.services.*;
 import ghidra.app.util.HelpTopics;
+import ghidra.app.util.datatype.DataTypeSelectionDialog;
 import ghidra.framework.Application;
 import ghidra.framework.main.OpenVersionedFileDialog;
 import ghidra.framework.model.*;
@@ -60,6 +62,7 @@ import ghidra.program.model.data.*;
 import ghidra.program.model.listing.DataTypeArchive;
 import ghidra.program.model.listing.Program;
 import ghidra.util.*;
+import ghidra.util.data.DataTypeParser.AllowedDataTypes;
 import ghidra.util.datastruct.LRUMap;
 import ghidra.util.exception.CancelledException;
 import ghidra.util.exception.VersionException;
@@ -84,10 +87,7 @@ import ghidra.util.task.TaskMonitor;
 )
 //@formatter:on
 public class DataTypeManagerPlugin extends ProgramPlugin
-		implements DomainObjectListener, DataTypeManagerService, DataTypeArchiveService,
-		PopupActionProvider {
-
-	private static final String EXTENSIONS_PATH_PREFIX = Path.GHIDRA_HOME + "/Extensions";
+		implements DomainObjectListener, DataTypeManagerService, PopupActionProvider {
 
 	private static final String SEARCH_PROVIDER_NAME = "Search DataTypes Provider";
 	private static final int RECENTLY_USED_CACHE_SIZE = 10;
@@ -193,6 +193,7 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 
 		// checking for the value maintains access-order of the archive
 		if (recentlyOpenedArchiveMap.get(absoluteFilePath) == null) {
+
 			RecentlyOpenedArchiveAction action =
 				new RecentlyOpenedArchiveAction(this, absoluteFilePath, RECENTLY_OPENED_MENU);
 			action.setHelpLocation(new HelpLocation(getName(), "Recent_Archives"));
@@ -208,15 +209,17 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 	 */
 	public void addRecentlyOpenedProjectArchive(String projectName, String pathname) {
 		String projectPathname = DataTypeManagerHandler.getProjectPathname(projectName, pathname);
-		if (recentlyOpenedArchiveMap.get(projectPathname) == null) {
-			RecentlyOpenedArchiveAction action = null;
-			if (getProjectArchiveFile(projectName, pathname) != null) {
-				action =
-					new RecentlyOpenedArchiveAction(this, projectPathname, RECENTLY_OPENED_MENU);
-				action.setHelpLocation(new HelpLocation(getName(), "Recent_Archives"));
-			}
-			recentlyOpenedArchiveMap.put(projectPathname, action);
+		if (recentlyOpenedArchiveMap.get(projectPathname) != null) {
+			return;
 		}
+
+		RecentlyOpenedArchiveAction action = null;
+		if (getProjectArchiveFile(projectName, pathname) != null) {
+			action = new RecentlyOpenedArchiveAction(this, projectPathname, RECENTLY_OPENED_MENU);
+			action.setHelpLocation(new HelpLocation(getName(), "Recent_Archives"));
+		}
+
+		recentlyOpenedArchiveMap.put(projectPathname, action);
 		updateRecentlyOpenedArchivesMenu();
 	}
 
@@ -281,16 +284,17 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 
 	@Override
 	public void domainObjectChanged(DomainObjectChangedEvent event) {
-		if (event.containsEvent(DomainObject.DO_OBJECT_RESTORED)) {
+		if (event.contains(DomainObjectEvent.RESTORED)) {
 			Object source = event.getSource();
 			if (source instanceof DataTypeManagerDomainObject) {
 				DataTypeManagerDomainObject domainObject = (DataTypeManagerDomainObject) source;
 				provider.domainObjectRestored(domainObject);
 				dataTypePropertyManager.domainObjectRestored(domainObject);
-				editorManager.domainObjectRestored(domainObject);
+				// NOTE: each editor that cares about a restored DataTypeManager must establish
+				// a DataTypeManagerChangeListener and will be notified via the restored method.
 			}
 		}
-		else if (event.containsEvent(DomainObject.DO_OBJECT_RENAMED)) {
+		else if (event.contains(DomainObjectEvent.RENAMED)) {
 			provider.programRenamed();
 		}
 	}
@@ -364,7 +368,7 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 	public DataTypesProvider createProvider() {
 
 		DataTypesProvider newProvider = new DataTypesProvider(this, SEARCH_PROVIDER_NAME, true);
-		newProvider.setIncludeDataTypeMembersInFilter(provider.includeDataMembersInSearch());
+		newProvider.setIncludeDataTypeMembersInFilter(provider.isIncludeDataMembersInSearch());
 		newProvider.setFilteringArrays(provider.isFilteringArrays());
 		newProvider.setFilteringPointers(provider.isFilteringPointers());
 		return newProvider;
@@ -419,61 +423,60 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 
 	private void createStandardArchivesMenu() {
 		installArchiveMap = new TreeMap<>();
-		for (ResourceFile archiveFile : Application
-				.findFilesByExtensionInApplication(FileDataTypeManager.SUFFIX)) {
+		String gdt = FileDataTypeManager.SUFFIX;
+		List<ResourceFile> gdts = Application.findFilesByExtensionInApplication(gdt);
+		for (ResourceFile archiveFile : gdts) {
 			Path path = new Path(archiveFile);
-			String absoluteFilePath = path.getPathAsString();
-			if (absoluteFilePath.indexOf("data/typeinfo") < 0) {
+			String absolutePath = path.getPathAsString();
+			if (!absolutePath.contains("/data/typeinfo/")) {
 				continue;
 			}
-			RecentlyOpenedArchiveAction action = new RecentlyOpenedArchiveAction(this,
-				absoluteFilePath, getShortArchivePath(absoluteFilePath), STANDARD_ARCHIVE_MENU);
+
+			RecentlyOpenedArchiveAction action =
+				new RecentlyOpenedArchiveAction(this, absolutePath, STANDARD_ARCHIVE_MENU);
 			action.setHelpLocation(new HelpLocation(getName(), "Standard_Archives"));
-			installArchiveMap.put(absoluteFilePath, action);
+			installArchiveMap.put(absolutePath, action);
 		}
 		for (DockingAction action : installArchiveMap.values()) {
 			tool.addLocalAction(provider, action);
 		}
 	}
 
-	private String getShortArchivePath(String fullPath) {
-		String path = fullPath;
-
-		String extensionPrefix = "";
-		if (fullPath.startsWith(EXTENSIONS_PATH_PREFIX)) {
-			int index = fullPath.indexOf("/", EXTENSIONS_PATH_PREFIX.length() + 1);
-			if (index >= 0) {
-				extensionPrefix =
-					fullPath.substring(EXTENSIONS_PATH_PREFIX.length() + 1, index) + ": ";
-				fullPath = fullPath.substring(index + 1);
-			}
-		}
-
-		int index1 = fullPath.lastIndexOf('/');
-		if (index1 >= 0) {
-			int index2 = fullPath.lastIndexOf('/', index1 - 1);
-			if (index2 >= 0) {
-				path = fullPath.substring(index2 + 1);
-				if (!path.startsWith("typeinfo/")) {
-					return extensionPrefix + path;
-				}
-			}
-			path = fullPath.substring(index1 + 1);
-		}
-		return extensionPrefix + path;
-	}
-
 	/**
 	 * Create the actions for the menu on the tool.
 	 */
 	private void createActions() {
 		createStandardArchivesMenu();
+
+		//@formatter:off
+		new ActionBuilder("Edit Data Type", getName())
+			.keyBinding("Control Shift D")
+			.onAction(this::edit)
+			.buildAndInstall(tool);
+		//@formatter:on
 	}
 
 	private void removeRecentAction(DockingAction action) {
 		tool.removeLocalAction(provider, action);
 	}
 
+	private void edit(ActionContext c) {
+		DataType dt = chooseType();
+		if (dt != null) {
+			edit(dt);
+		}
+	}
+
+	private DataType chooseType() {
+
+		int noSizeRestriction = -1;
+		DataTypeSelectionDialog selectionDialog =
+			new DataTypeSelectionDialog(tool, null, noSizeRestriction, AllowedDataTypes.ALL);
+
+		tool.showDialog(selectionDialog);
+		return selectionDialog.getUserChosenDataType();
+	}
+
 //**********************************************************************************************
 //	DataTypeManagerService methods
 //**********************************************************************************************
@@ -490,20 +493,14 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 
 	@Override
 	public void edit(DataType dt) {
-		DataTypeManager dataTypeManager = dt.getDataTypeManager();
-		if (dataTypeManager == null) {
-			throw new IllegalArgumentException(
-				"DataType " + dt.getPathName() + " has no DataTypeManager!  Make sure the " +
-					"given DataType has been resolved by a DataTypeManager");
-		}
-		CategoryPath categoryPath = dt.getCategoryPath();
-		if (categoryPath == null) {
-			throw new IllegalArgumentException(
-				"DataType " + dt.getName() + " has no category path!");
-		}
 		editorManager.edit(dt);
 	}
 
+	@Override
+	public void edit(Structure dt, String fieldName) {
+		editorManager.edit(dt, fieldName);
+	}
+
 	@Override
 	public DataTypeManager getBuiltInDataTypesManager() {
 		return dataTypeManagerHandler.getBuiltInDataTypesManager();
@@ -580,9 +577,8 @@ public class DataTypeManagerPlugin extends ProgramPlugin
 
 	public void openProjectDataTypeArchive() {
 
-		OpenVersionedFileDialog<DataTypeArchive> dialog =
-			new OpenVersionedFileDialog<>(tool, "Open Project Data Type Archive",
-				DataTypeArchive.class);
+		OpenVersionedFileDialog<DataTypeArchive> dialog = new OpenVersionedFileDialog<>(tool,
+			"Open Project Data Type Archive", DataTypeArchive.class);
 		dialog.setHelpLocation(new HelpLocation(HelpTopics.PROGRAM, "Open_File_Dialog"));
 		dialog.addOkActionListener(ev -> {
 			DomainFile domainFile = dialog.getDomainFile();
