@@ -5,9 +5,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -587,7 +587,6 @@ public abstract class AbstractVTMatchTableModel extends AddressBasedTableModel<V
 							renderer.setToolTipText(symbol.getName(true));
 						}
 						if (symbolInspector != null) {
-							symbolInspector.setProgram(symbol.getProgram());
 							renderer.setForeground(symbolInspector.getColor(symbol));
 						}
 					}
@@ -716,7 +715,6 @@ public abstract class AbstractVTMatchTableModel extends AddressBasedTableModel<V
 					Address address = displayableAddress.getAddress();
 					if (!address.isMemoryAddress() && symbolInspector != null) {
 						Symbol s = program.getSymbolTable().getPrimarySymbol(address);
-						symbolInspector.setProgram(program);
 						Color c = (s != null) ? symbolInspector.getColor(s) : FG_ERROR;
 						setForeground(c);
 					}
@@ -826,7 +824,6 @@ public abstract class AbstractVTMatchTableModel extends AddressBasedTableModel<V
 							renderer.setToolTipText(symbol.getName(true));
 						}
 						if (symbolInspector != null) {
-							symbolInspector.setProgram(symbol.getProgram());
 							renderer.setForeground(symbolInspector.getColor(symbol));
 						}
 					}
@@ -955,7 +952,6 @@ public abstract class AbstractVTMatchTableModel extends AddressBasedTableModel<V
 					Address address = displayableAddress.getAddress();
 					if (!address.isMemoryAddress() && symbolInspector != null) {
 						Symbol s = program.getSymbolTable().getPrimarySymbol(address);
-						symbolInspector.setProgram(program);
 						Color c = (s != null) ? symbolInspector.getColor(s) : FG_ERROR;
 						setForeground(c);
 					}
