@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,8 +15,7 @@
  */
 package generic.test;
 
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.*;
 
 import java.awt.*;
 import java.awt.event.*;
@@ -35,6 +34,7 @@ import javax.swing.tree.*;
 
 import org.junit.Assert;
 
+import ghidra.framework.ApplicationConfiguration;
 import ghidra.util.*;
 import ghidra.util.datastruct.WeakSet;
 import ghidra.util.exception.AssertException;
@@ -49,6 +49,18 @@ import utility.function.ExceptionalCallback;
  * should use AbstractGenericTest instead
  */
 public class AbstractGuiTest extends AbstractGenericTest {
+
+	@Override
+	protected ApplicationConfiguration createApplicationConfiguration() {
+		// A simple way to signal that Gui tests are not headless
+		return new ApplicationConfiguration() {
+			@Override
+			public boolean isHeadless() {
+				return false;
+			}
+		};
+	}
+
 	/**
 	 * Gets all windows in the system (including Frames).
 	 *
@@ -358,29 +370,6 @@ public class AbstractGuiTest extends AbstractGenericTest {
 		return null;
 	}
 
-	public static List<Component> findComponentsByName(Container container, String componentName,
-			boolean checkOwnedWindows) {
-
-		List<Component> retList = new ArrayList<>();
-
-		Component[] components = container.getComponents();
-		for (Component component : components) {
-			if (component == null) {
-				continue;
-			}
-			String name = component.getName();
-			if (name != null && name.equals(componentName)) {
-				retList.add(component);
-			}
-			else if (component instanceof Container) {
-				retList.addAll(
-					findComponentsByName((Container) component, componentName, checkOwnedWindows));
-			}
-
-		}
-		return retList;
-	}
-
 	public static JButton findButtonByIcon(Container container, Icon icon) {
 		Component[] comps = container.getComponents();
 		for (Component element : comps) {
@@ -403,7 +392,7 @@ public class AbstractGuiTest extends AbstractGenericTest {
 	}
 
 	/**
-	 * Searches the subcomponents of the the given container and returns the
+	 * Searches the subcomponents of the given container and returns the
 	 * JButton that has the specified text.
 	 *
 	 * @param container the container to search
@@ -429,6 +418,18 @@ public class AbstractGuiTest extends AbstractGenericTest {
 		return null;
 	}
 
+	/**
+	 * Searches the sub-components of the given container and returns the AbstractButton that has 
+	 * the specified name.
+	 *
+	 * @param container container to search
+	 * @param name the button name
+	 * @return null if the button was not found
+	 */
+	public static AbstractButton findButtonByName(Container container, String name) {
+		return findAbstractButtonByName(container, name);
+	}
+
 	/**
 	 * Searches the sub-components of the given container and returns the
 	 * AbstractButton that has the specified text.
@@ -470,7 +471,6 @@ public class AbstractGuiTest extends AbstractGenericTest {
 	 * @return null if the button was not found
 	 */
 	public static AbstractButton findAbstractButtonByName(Container container, String name) {
-
 		Component[] comp = container.getComponents();
 		for (Component element : comp) {
 			if ((element instanceof AbstractButton) &&
@@ -661,12 +661,26 @@ public class AbstractGuiTest extends AbstractGenericTest {
 	 * @param s the supplier
 	 * @return the value returned by the supplier
 	 */
-	public static <T> T runSwing(Supplier<T> s) {
+	public static <T> T getSwing(Supplier<T> s) {
 		AtomicReference<T> ref = new AtomicReference<>();
 		runSwing(() -> ref.set(s.get()));
 		return ref.get();
 	}
 
+	/**
+	 * Returns the value from the given {@link Supplier}, invoking the call in
+	 * the Swing thread. This is useful when you may have values that are being
+	 * changed on the Swing thread and you need the test thread to see the
+	 * changes.
+	 *
+	 * @param s the supplier
+	 * @return the value returned by the supplier
+	 * @see #getSwing(Supplier)
+	 */
+	public static <T> T runSwing(Supplier<T> s) {
+		return getSwing(s);
+	}
+
 	/**
 	 * Run the given code snippet on the Swing thread and wait for it to finish
 	 * @param r the runnable code snippet
@@ -1110,8 +1124,8 @@ public class AbstractGuiTest extends AbstractGenericTest {
 		if (expected.getRGB() == actual.getRGB()) {
 			return;
 		}
-		fail("Expected: [" + expected.getClass().getSimpleName() + "]" + expected +
-			", but got: [" + actual.getClass().getSimpleName() + "]" + actual);
+		fail("Expected: [" + expected.getClass().getSimpleName() + "]" + expected + ", but got: [" +
+			actual.getClass().getSimpleName() + "]" + actual);
 	}
 
 	public static void printMemory() {
